Module: Google::Apis::ConfigV1
- Defined in:
- lib/google/apis/config_v1.rb,
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/service.rb,
lib/google/apis/config_v1/gem_version.rb,
lib/google/apis/config_v1/representations.rb
Overview
Infrastructure Manager API
Creates and manages Google Cloud Platform resources and infrastructure.
Defined Under Namespace
Classes: ApplyResults, AuditConfig, AuditLogConfig, AutoMigrationConfig, Binding, CancelOperationRequest, ConfigService, DeleteStatefileRequest, Deployment, DeploymentGroup, DeploymentGroupRevision, DeploymentOperationMetadata, DeploymentOperationSummary, DeploymentSource, DeploymentSpec, DeploymentUnit, DeploymentUnitProgress, DeprovisionDeploymentGroupRequest, Empty, ExportDeploymentStatefileRequest, ExportPreviewResultRequest, ExportPreviewResultResponse, ExportRevisionStatefileRequest, Expr, ExternalValueSource, GitSource, ImportStatefileRequest, ListDeploymentGroupRevisionsResponse, ListDeploymentGroupsResponse, ListDeploymentsResponse, ListLocationsResponse, ListOperationsResponse, ListPreviewsResponse, ListResourceChangesResponse, ListResourceDriftsResponse, ListResourcesResponse, ListRevisionsResponse, ListTerraformVersionsResponse, Location, LockDeploymentRequest, LockInfo, Operation, OperationMetadata, Policy, Preview, PreviewArtifacts, PreviewOperationMetadata, PreviewResult, PropertyChange, PropertyDrift, ProviderConfig, ProvisionDeploymentGroupOperationMetadata, ProvisionDeploymentGroupRequest, Resource, ResourceCaiInfo, ResourceChange, ResourceChangeTerraformInfo, ResourceDrift, ResourceDriftTerraformInfo, ResourceTerraformInfo, Revision, SetIamPolicyRequest, Statefile, Status, TerraformBlueprint, TerraformError, TerraformOutput, TerraformVariable, TerraformVersion, TestIamPermissionsRequest, TestIamPermissionsResponse, UnlockDeploymentRequest
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-config_v1 gem
"0.18.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260324"- VERSION =
Version of the Infrastructure Manager API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'