Class: Google::Apis::ConfigV1::DeleteStatefileRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

A request to delete a state file passed to a 'DeleteStatefile' call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteStatefileRequest

Returns a new instance of DeleteStatefileRequest.



286
287
288
# File 'lib/google/apis/config_v1/classes.rb', line 286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lock_idFixnum

Required. Lock ID of the lock file to verify that the user who is deleting the state file previously locked the Deployment. Corresponds to the JSON property lockId

Returns:

  • (Fixnum)


284
285
286
# File 'lib/google/apis/config_v1/classes.rb', line 284

def lock_id
  @lock_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



291
292
293
# File 'lib/google/apis/config_v1/classes.rb', line 291

def update!(**args)
  @lock_id = args[:lock_id] if args.key?(:lock_id)
end