Class: Google::Apis::ConfigV1::DeploymentSpec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

Spec for a deployment to be created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeploymentSpec

Returns a new instance of DeploymentSpec.



743
744
745
# File 'lib/google/apis/config_v1/classes.rb', line 743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentGoogle::Apis::ConfigV1::Deployment

A Deployment is a group of resources and configs managed and provisioned by Infra Manager. Corresponds to the JSON property deployment



735
736
737
# File 'lib/google/apis/config_v1/classes.rb', line 735

def deployment
  @deployment
end

#deployment_idString

Required. The id of the deployment to be created which doesn't include the project id and location. Corresponds to the JSON property deploymentId

Returns:

  • (String)


741
742
743
# File 'lib/google/apis/config_v1/classes.rb', line 741

def deployment_id
  @deployment_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



748
749
750
751
# File 'lib/google/apis/config_v1/classes.rb', line 748

def update!(**args)
  @deployment = args[:deployment] if args.key?(:deployment)
  @deployment_id = args[:deployment_id] if args.key?(:deployment_id)
end