Class: Google::Apis::ConfigV1::DeploymentUnitProgress

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

The progress of a deployment unit provisioning or deprovisioning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeploymentUnitProgress

Returns a new instance of DeploymentUnitProgress.



842
843
844
# File 'lib/google/apis/config_v1/classes.rb', line 842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentString

Output only. The name of the deployment to be provisioned. Format: 'projects/ project/locations/location/deployments/deployment'. Corresponds to the JSON property deployment

Returns:

  • (String)


805
806
807
# File 'lib/google/apis/config_v1/classes.rb', line 805

def deployment
  @deployment
end

#deployment_operation_summaryGoogle::Apis::ConfigV1::DeploymentOperationSummary

The summary of the deployment operation. Corresponds to the JSON property deploymentOperationSummary



810
811
812
# File 'lib/google/apis/config_v1/classes.rb', line 810

def deployment_operation_summary
  @deployment_operation_summary
end

#errorGoogle::Apis::ConfigV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



820
821
822
# File 'lib/google/apis/config_v1/classes.rb', line 820

def error
  @error
end

#intentString

Output only. The intent of the deployment unit. Corresponds to the JSON property intent

Returns:

  • (String)


825
826
827
# File 'lib/google/apis/config_v1/classes.rb', line 825

def intent
  @intent
end

#stateString

Output only. The current step of the deployment unit provisioning. Corresponds to the JSON property state

Returns:

  • (String)


830
831
832
# File 'lib/google/apis/config_v1/classes.rb', line 830

def state
  @state
end

#state_descriptionString

Output only. Additional information regarding the current state. Corresponds to the JSON property stateDescription

Returns:

  • (String)


835
836
837
# File 'lib/google/apis/config_v1/classes.rb', line 835

def state_description
  @state_description
end

#unit_idString

Output only. The unit id of the deployment unit to be provisioned. Corresponds to the JSON property unitId

Returns:

  • (String)


840
841
842
# File 'lib/google/apis/config_v1/classes.rb', line 840

def unit_id
  @unit_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



847
848
849
850
851
852
853
854
855
# File 'lib/google/apis/config_v1/classes.rb', line 847

def update!(**args)
  @deployment = args[:deployment] if args.key?(:deployment)
  @deployment_operation_summary = args[:deployment_operation_summary] if args.key?(:deployment_operation_summary)
  @error = args[:error] if args.key?(:error)
  @intent = args[:intent] if args.key?(:intent)
  @state = args[:state] if args.key?(:state)
  @state_description = args[:state_description] if args.key?(:state_description)
  @unit_id = args[:unit_id] if args.key?(:unit_id)
end