Class: Google::Apis::ConfigV1::DeprovisionDeploymentGroupRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

The request message for the DeprovisionDeploymentGroup method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeprovisionDeploymentGroupRequest

Returns a new instance of DeprovisionDeploymentGroupRequest.



878
879
880
# File 'lib/google/apis/config_v1/classes.rb', line 878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delete_policyString

Optional. Policy on how resources within each deployment should be handled during deletion. This policy is applied globally to the deletion of all deployments in this group. This corresponds to the 'delete_policy' field in DeleteDeploymentRequest. Corresponds to the JSON property deletePolicy

Returns:

  • (String)


868
869
870
# File 'lib/google/apis/config_v1/classes.rb', line 868

def delete_policy
  @delete_policy
end

#forceBoolean Also known as: force?

Optional. If set to true, this option is propagated to the deletion of each deployment in the group. This corresponds to the 'force' field in DeleteDeploymentRequest. Corresponds to the JSON property force

Returns:

  • (Boolean)


875
876
877
# File 'lib/google/apis/config_v1/classes.rb', line 875

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



883
884
885
886
# File 'lib/google/apis/config_v1/classes.rb', line 883

def update!(**args)
  @delete_policy = args[:delete_policy] if args.key?(:delete_policy)
  @force = args[:force] if args.key?(:force)
end