Class: Google::Apis::ConfigV1::ExportDeploymentStatefileRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

A request to export a state file passed to a 'ExportDeploymentStatefile' call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportDeploymentStatefileRequest

Returns a new instance of ExportDeploymentStatefileRequest.



917
918
919
# File 'lib/google/apis/config_v1/classes.rb', line 917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#draftBoolean Also known as: draft?

Optional. If this flag is set to true, the exported deployment state file will be the draft state. This will enable the draft file to be validated before copying it over to the working state on unlock. Corresponds to the JSON property draft

Returns:

  • (Boolean)


914
915
916
# File 'lib/google/apis/config_v1/classes.rb', line 914

def draft
  @draft
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



922
923
924
# File 'lib/google/apis/config_v1/classes.rb', line 922

def update!(**args)
  @draft = args[:draft] if args.key?(:draft)
end