Class: Google::Apis::ConfigV1::ImportStatefileRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

A request to import a state file passed to a 'ImportStatefile' call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportStatefileRequest

Returns a new instance of ImportStatefileRequest.



1086
1087
1088
# File 'lib/google/apis/config_v1/classes.rb', line 1086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lock_idFixnum

Required. Lock ID of the lock file to verify that the user who is importing the state file previously locked the Deployment. Corresponds to the JSON property lockId

Returns:

  • (Fixnum)


1084
1085
1086
# File 'lib/google/apis/config_v1/classes.rb', line 1084

def lock_id
  @lock_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1091
1092
1093
# File 'lib/google/apis/config_v1/classes.rb', line 1091

def update!(**args)
  @lock_id = args[:lock_id] if args.key?(:lock_id)
end