Class: Google::Apis::ConfigV1::ListResourceDriftsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

A response to a 'ListResourceDrifts' call. Contains a list of ResourceDrifts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListResourceDriftsResponse

Returns a new instance of ListResourceDriftsResponse.



1337
1338
1339
# File 'lib/google/apis/config_v1/classes.rb', line 1337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the 'ListResourceDrifts' method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1325
1326
1327
# File 'lib/google/apis/config_v1/classes.rb', line 1325

def next_page_token
  @next_page_token
end

#resource_driftsArray<Google::Apis::ConfigV1::ResourceDrift>

List of ResourceDrifts. Corresponds to the JSON property resourceDrifts



1330
1331
1332
# File 'lib/google/apis/config_v1/classes.rb', line 1330

def resource_drifts
  @resource_drifts
end

#unreachableArray<String>

Unreachable resources, if any. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1335
1336
1337
# File 'lib/google/apis/config_v1/classes.rb', line 1335

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1342
1343
1344
1345
1346
# File 'lib/google/apis/config_v1/classes.rb', line 1342

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resource_drifts = args[:resource_drifts] if args.key?(:resource_drifts)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end