Class: Google::Apis::ConfigV1::ListResourcesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

A response to a 'ListResources' call. Contains a list of Resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListResourcesResponse

Returns a new instance of ListResourcesResponse.



1369
1370
1371
# File 'lib/google/apis/config_v1/classes.rb', line 1369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the 'ListResources' method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/config_v1/classes.rb', line 1357

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::ConfigV1::Resource>

List of Resources. Corresponds to the JSON property resources



1362
1363
1364
# File 'lib/google/apis/config_v1/classes.rb', line 1362

def resources
  @resources
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1367
1368
1369
# File 'lib/google/apis/config_v1/classes.rb', line 1367

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1374
1375
1376
1377
1378
# File 'lib/google/apis/config_v1/classes.rb', line 1374

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end