Class: Google::Apis::ConfigV1::LockInfo
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::LockInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
Details about the lock which locked the deployment.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Time that the lock was taken.
-
#info ⇒ String
Extra information to store with the lock, provided by the caller.
-
#lock_id ⇒ Fixnum
Unique ID for the lock to be overridden with generation ID in the backend.
-
#operation ⇒ String
Terraform operation, provided by the caller.
-
#version ⇒ String
Terraform version Corresponds to the JSON property
version. -
#who ⇒ String
user@hostname when available Corresponds to the JSON property
who.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LockInfo
constructor
A new instance of LockInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LockInfo
Returns a new instance of LockInfo.
1539 1540 1541 |
# File 'lib/google/apis/config_v1/classes.rb', line 1539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Time that the lock was taken.
Corresponds to the JSON property createTime
1512 1513 1514 |
# File 'lib/google/apis/config_v1/classes.rb', line 1512 def create_time @create_time end |
#info ⇒ String
Extra information to store with the lock, provided by the caller.
Corresponds to the JSON property info
1517 1518 1519 |
# File 'lib/google/apis/config_v1/classes.rb', line 1517 def info @info end |
#lock_id ⇒ Fixnum
Unique ID for the lock to be overridden with generation ID in the backend.
Corresponds to the JSON property lockId
1522 1523 1524 |
# File 'lib/google/apis/config_v1/classes.rb', line 1522 def lock_id @lock_id end |
#operation ⇒ String
Terraform operation, provided by the caller.
Corresponds to the JSON property operation
1527 1528 1529 |
# File 'lib/google/apis/config_v1/classes.rb', line 1527 def operation @operation end |
#version ⇒ String
Terraform version
Corresponds to the JSON property version
1532 1533 1534 |
# File 'lib/google/apis/config_v1/classes.rb', line 1532 def version @version end |
#who ⇒ String
user@hostname when available
Corresponds to the JSON property who
1537 1538 1539 |
# File 'lib/google/apis/config_v1/classes.rb', line 1537 def who @who end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1544 1545 1546 1547 1548 1549 1550 1551 |
# File 'lib/google/apis/config_v1/classes.rb', line 1544 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @info = args[:info] if args.key?(:info) @lock_id = args[:lock_id] if args.key?(:lock_id) @operation = args[:operation] if args.key?(:operation) @version = args[:version] if args.key?(:version) @who = args[:who] if args.key?(:who) end |