Class: Google::Apis::ConfigV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1675
1676
1677
# File 'lib/google/apis/config_v1/classes.rb', line 1675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1623
1624
1625
# File 'lib/google/apis/config_v1/classes.rb', line 1623

def api_version
  @api_version
end

#create_timeString

Output only. Time when the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1628
1629
1630
# File 'lib/google/apis/config_v1/classes.rb', line 1628

def create_time
  @create_time
end

#deployment_metadataGoogle::Apis::ConfigV1::DeploymentOperationMetadata

Ephemeral metadata content describing the state of a deployment operation. Corresponds to the JSON property deploymentMetadata



1633
1634
1635
# File 'lib/google/apis/config_v1/classes.rb', line 1633

def 
  @deployment_metadata
end

#end_timeString

Output only. Time when the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1638
1639
1640
# File 'lib/google/apis/config_v1/classes.rb', line 1638

def end_time
  @end_time
end

#preview_metadataGoogle::Apis::ConfigV1::PreviewOperationMetadata

Ephemeral metadata content describing the state of a preview operation. Corresponds to the JSON property previewMetadata



1643
1644
1645
# File 'lib/google/apis/config_v1/classes.rb', line 1643

def 
  @preview_metadata
end

#provision_deployment_group_metadataGoogle::Apis::ConfigV1::ProvisionDeploymentGroupOperationMetadata

Operation metadata for ProvisionDeploymentGroup and DeprovisionDeploymentGroup long-running operations. Corresponds to the JSON property provisionDeploymentGroupMetadata



1649
1650
1651
# File 'lib/google/apis/config_v1/classes.rb', line 1649

def 
  @provision_deployment_group_metadata
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1657
1658
1659
# File 'lib/google/apis/config_v1/classes.rb', line 1657

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/config_v1/classes.rb', line 1663

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1668
1669
1670
# File 'lib/google/apis/config_v1/classes.rb', line 1668

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1673
1674
1675
# File 'lib/google/apis/config_v1/classes.rb', line 1673

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
# File 'lib/google/apis/config_v1/classes.rb', line 1680

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment_metadata = args[:deployment_metadata] if args.key?(:deployment_metadata)
  @end_time = args[:end_time] if args.key?(:end_time)
  @preview_metadata = args[:preview_metadata] if args.key?(:preview_metadata)
  @provision_deployment_group_metadata = args[:provision_deployment_group_metadata] if args.key?(:provision_deployment_group_metadata)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end