Class: Google::Apis::ConfigV1::ResourceTerraformInfo
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::ResourceTerraformInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
Terraform info of a Resource.
Instance Attribute Summary collapse
-
#address ⇒ String
TF resource address that uniquely identifies this resource within this deployment.
-
#id ⇒ String
ID attribute of the TF resource Corresponds to the JSON property
id. -
#type ⇒ String
TF resource type Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceTerraformInfo
constructor
A new instance of ResourceTerraformInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceTerraformInfo
Returns a new instance of ResourceTerraformInfo.
2438 2439 2440 |
# File 'lib/google/apis/config_v1/classes.rb', line 2438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
TF resource address that uniquely identifies this resource within this
deployment.
Corresponds to the JSON property address
2426 2427 2428 |
# File 'lib/google/apis/config_v1/classes.rb', line 2426 def address @address end |
#id ⇒ String
ID attribute of the TF resource
Corresponds to the JSON property id
2431 2432 2433 |
# File 'lib/google/apis/config_v1/classes.rb', line 2431 def id @id end |
#type ⇒ String
TF resource type
Corresponds to the JSON property type
2436 2437 2438 |
# File 'lib/google/apis/config_v1/classes.rb', line 2436 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2443 2444 2445 2446 2447 |
# File 'lib/google/apis/config_v1/classes.rb', line 2443 def update!(**args) @address = args[:address] if args.key?(:address) @id = args[:id] if args.key?(:id) @type = args[:type] if args.key?(:type) end |