Class: Google::Apis::ConfigV1::TerraformBlueprint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

TerraformBlueprint describes the source of a Terraform root module which describes the resources and configs to be deployed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TerraformBlueprint

Returns a new instance of TerraformBlueprint.



2759
2760
2761
# File 'lib/google/apis/config_v1/classes.rb', line 2759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_valuesHash<String,Google::Apis::ConfigV1::ExternalValueSource>

Optional. Map of input variable names in this blueprint to configurations for importing values from external sources. Corresponds to the JSON property externalValues



2740
2741
2742
# File 'lib/google/apis/config_v1/classes.rb', line 2740

def external_values
  @external_values
end

#gcs_sourceString

URI of an object in Google Cloud Storage. Format: gs://bucket/objectURI may also specify an object version for zipped objects. Format: `gs://`bucket`/` object`#`version Corresponds to the JSON property gcsSource

Returns:

  • (String)


2747
2748
2749
# File 'lib/google/apis/config_v1/classes.rb', line 2747

def gcs_source
  @gcs_source
end

#git_sourceGoogle::Apis::ConfigV1::GitSource

A set of files in a Git repository. Corresponds to the JSON property gitSource



2752
2753
2754
# File 'lib/google/apis/config_v1/classes.rb', line 2752

def git_source
  @git_source
end

#input_valuesHash<String,Google::Apis::ConfigV1::TerraformVariable>

Optional. Input variable values for the Terraform blueprint. Corresponds to the JSON property inputValues



2757
2758
2759
# File 'lib/google/apis/config_v1/classes.rb', line 2757

def input_values
  @input_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2764
2765
2766
2767
2768
2769
# File 'lib/google/apis/config_v1/classes.rb', line 2764

def update!(**args)
  @external_values = args[:external_values] if args.key?(:external_values)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @git_source = args[:git_source] if args.key?(:git_source)
  @input_values = args[:input_values] if args.key?(:input_values)
end