Class: Google::Apis::ConfigV1::DeploymentGroup
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::DeploymentGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
A DeploymentGroup is a collection of DeploymentUnits that in a DAG-like structure.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#deployment_units ⇒ Array<Google::Apis::ConfigV1::DeploymentUnit>
The deployment units of the deployment group in a DAG like structure.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#provisioning_error ⇒ Google::Apis::ConfigV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#provisioning_state ⇒ String
Output only.
-
#provisioning_state_description ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_description ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeploymentGroup
constructor
A new instance of DeploymentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeploymentGroup
Returns a new instance of DeploymentGroup.
553 554 555 |
# File 'lib/google/apis/config_v1/classes.rb', line 553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Arbitrary key-value metadata storage e.g. to help client tools
identify deployment group during automation. See https://google.aip.dev/148#
annotations for details on format and size limitations.
Corresponds to the JSON property annotations
492 493 494 |
# File 'lib/google/apis/config_v1/classes.rb', line 492 def annotations @annotations end |
#create_time ⇒ String
Output only. Time when the deployment group was created.
Corresponds to the JSON property createTime
497 498 499 |
# File 'lib/google/apis/config_v1/classes.rb', line 497 def create_time @create_time end |
#deployment_units ⇒ Array<Google::Apis::ConfigV1::DeploymentUnit>
The deployment units of the deployment group in a DAG like structure. When a
deployment group is being provisioned, the deployment units are deployed in a
DAG order. The provided units must be in a DAG order, otherwise an error will
be returned.
Corresponds to the JSON property deploymentUnits
505 506 507 |
# File 'lib/google/apis/config_v1/classes.rb', line 505 def deployment_units @deployment_units end |
#labels ⇒ Hash<String,String>
Optional. User-defined metadata for the deployment group.
Corresponds to the JSON property labels
510 511 512 |
# File 'lib/google/apis/config_v1/classes.rb', line 510 def labels @labels end |
#name ⇒ String
Identifier. The name of the deployment group. Format: 'projects/project_id/
locations/location/deploymentGroups/deployment_group'.
Corresponds to the JSON property name
516 517 518 |
# File 'lib/google/apis/config_v1/classes.rb', line 516 def name @name end |
#provisioning_error ⇒ Google::Apis::ConfigV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property provisioningError
526 527 528 |
# File 'lib/google/apis/config_v1/classes.rb', line 526 def provisioning_error @provisioning_error end |
#provisioning_state ⇒ String
Output only. The provisioning state of the deployment group.
Corresponds to the JSON property provisioningState
531 532 533 |
# File 'lib/google/apis/config_v1/classes.rb', line 531 def provisioning_state @provisioning_state end |
#provisioning_state_description ⇒ String
Output only. Additional information regarding the current provisioning state.
Corresponds to the JSON property provisioningStateDescription
536 537 538 |
# File 'lib/google/apis/config_v1/classes.rb', line 536 def provisioning_state_description @provisioning_state_description end |
#state ⇒ String
Output only. Current state of the deployment group.
Corresponds to the JSON property state
541 542 543 |
# File 'lib/google/apis/config_v1/classes.rb', line 541 def state @state end |
#state_description ⇒ String
Output only. Additional information regarding the current state.
Corresponds to the JSON property stateDescription
546 547 548 |
# File 'lib/google/apis/config_v1/classes.rb', line 546 def state_description @state_description end |
#update_time ⇒ String
Output only. Time when the deployment group was last updated.
Corresponds to the JSON property updateTime
551 552 553 |
# File 'lib/google/apis/config_v1/classes.rb', line 551 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
558 559 560 561 562 563 564 565 566 567 568 569 570 |
# File 'lib/google/apis/config_v1/classes.rb', line 558 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @deployment_units = args[:deployment_units] if args.key?(:deployment_units) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @provisioning_error = args[:provisioning_error] if args.key?(:provisioning_error) @provisioning_state = args[:provisioning_state] if args.key?(:provisioning_state) @provisioning_state_description = args[:provisioning_state_description] if args.key?(:provisioning_state_description) @state = args[:state] if args.key?(:state) @state_description = args[:state_description] if args.key?(:state_description) @update_time = args[:update_time] if args.key?(:update_time) end |