Class: Google::Apis::ConfigV1::DeploymentSource
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::DeploymentSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
Configuration for a value sourced from a Deployment.
Instance Attribute Summary collapse
-
#deployment ⇒ String
Required.
-
#output_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeploymentSource
constructor
A new instance of DeploymentSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeploymentSource
Returns a new instance of DeploymentSource.
716 717 718 |
# File 'lib/google/apis/config_v1/classes.rb', line 716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment ⇒ String
Required. The resource name of the source Deployment to import the output from.
Format: projects/project/locations/location/deployments/deployment The
source deployment must be in the same project and location.
Corresponds to the JSON property deployment
708 709 710 |
# File 'lib/google/apis/config_v1/classes.rb', line 708 def deployment @deployment end |
#output_name ⇒ String
Required. The name of the output variable in the source deployment's latest
successfully applied revision.
Corresponds to the JSON property outputName
714 715 716 |
# File 'lib/google/apis/config_v1/classes.rb', line 714 def output_name @output_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
721 722 723 724 |
# File 'lib/google/apis/config_v1/classes.rb', line 721 def update!(**args) @deployment = args[:deployment] if args.key?(:deployment) @output_name = args[:output_name] if args.key?(:output_name) end |