Class: Google::Apis::ConfigV1::DeploymentUnit
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::DeploymentUnit
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
A DeploymentUnit is a container for a deployment and its dependencies. An
existing deployment can be provided directly in the unit, or the unit can act
as a placeholder to define the DAG, with the deployment specs supplied in a
provisionDeploymentRequest.
Instance Attribute Summary collapse
-
#dependencies ⇒ Array<String>
Required.
-
#deployment ⇒ String
Optional.
-
#id ⇒ String
The id of the deployment unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeploymentUnit
constructor
A new instance of DeploymentUnit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeploymentUnit
Returns a new instance of DeploymentUnit.
778 779 780 |
# File 'lib/google/apis/config_v1/classes.rb', line 778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dependencies ⇒ Array<String>
Required. The IDs of the deployment units within the deployment group that
this unit depends on.
Corresponds to the JSON property dependencies
765 766 767 |
# File 'lib/google/apis/config_v1/classes.rb', line 765 def dependencies @dependencies end |
#deployment ⇒ String
Optional. The name of the deployment to be provisioned. Format: 'projects/
project_id/locations/location/deployments/deployment'.
Corresponds to the JSON property deployment
771 772 773 |
# File 'lib/google/apis/config_v1/classes.rb', line 771 def deployment @deployment end |
#id ⇒ String
The id of the deployment unit. Must be unique within the deployment group.
Corresponds to the JSON property id
776 777 778 |
# File 'lib/google/apis/config_v1/classes.rb', line 776 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
783 784 785 786 787 |
# File 'lib/google/apis/config_v1/classes.rb', line 783 def update!(**args) @dependencies = args[:dependencies] if args.key?(:dependencies) @deployment = args[:deployment] if args.key?(:deployment) @id = args[:id] if args.key?(:id) end |