Class: Google::Apis::ConfigV1::DeploymentUnitProgress

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

The progress of a deployment unit provisioning or deprovisioning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeploymentUnitProgress

Returns a new instance of DeploymentUnitProgress.



835
836
837
# File 'lib/google/apis/config_v1/classes.rb', line 835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentString

Output only. The name of the deployment to be provisioned. Format: 'projects/ project/locations/location/deployments/deployment'. Corresponds to the JSON property deployment

Returns:

  • (String)


798
799
800
# File 'lib/google/apis/config_v1/classes.rb', line 798

def deployment
  @deployment
end

#deployment_operation_summaryGoogle::Apis::ConfigV1::DeploymentOperationSummary

The summary of the deployment operation. Corresponds to the JSON property deploymentOperationSummary



803
804
805
# File 'lib/google/apis/config_v1/classes.rb', line 803

def deployment_operation_summary
  @deployment_operation_summary
end

#errorGoogle::Apis::ConfigV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



813
814
815
# File 'lib/google/apis/config_v1/classes.rb', line 813

def error
  @error
end

#intentString

Output only. The intent of the deployment unit. Corresponds to the JSON property intent

Returns:

  • (String)


818
819
820
# File 'lib/google/apis/config_v1/classes.rb', line 818

def intent
  @intent
end

#stateString

Output only. The current step of the deployment unit provisioning. Corresponds to the JSON property state

Returns:

  • (String)


823
824
825
# File 'lib/google/apis/config_v1/classes.rb', line 823

def state
  @state
end

#state_descriptionString

Output only. Additional information regarding the current state. Corresponds to the JSON property stateDescription

Returns:

  • (String)


828
829
830
# File 'lib/google/apis/config_v1/classes.rb', line 828

def state_description
  @state_description
end

#unit_idString

Output only. The unit id of the deployment unit to be provisioned. Corresponds to the JSON property unitId

Returns:

  • (String)


833
834
835
# File 'lib/google/apis/config_v1/classes.rb', line 833

def unit_id
  @unit_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



840
841
842
843
844
845
846
847
848
# File 'lib/google/apis/config_v1/classes.rb', line 840

def update!(**args)
  @deployment = args[:deployment] if args.key?(:deployment)
  @deployment_operation_summary = args[:deployment_operation_summary] if args.key?(:deployment_operation_summary)
  @error = args[:error] if args.key?(:error)
  @intent = args[:intent] if args.key?(:intent)
  @state = args[:state] if args.key?(:state)
  @state_description = args[:state_description] if args.key?(:state_description)
  @unit_id = args[:unit_id] if args.key?(:unit_id)
end