Class: Google::Apis::ConfigV1::ListResourceChangesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::ListResourceChangesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
A response to a 'ListResourceChanges' call. Contains a list of ResourceChanges.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the 'ListResourceChanges' method.
-
#resource_changes ⇒ Array<Google::Apis::ConfigV1::ResourceChange>
List of ResourceChanges.
-
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListResourceChangesResponse
constructor
A new instance of ListResourceChangesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListResourceChangesResponse
Returns a new instance of ListResourceChangesResponse.
1297 1298 1299 |
# File 'lib/google/apis/config_v1/classes.rb', line 1297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the 'ListResourceChanges'
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
1285 1286 1287 |
# File 'lib/google/apis/config_v1/classes.rb', line 1285 def next_page_token @next_page_token end |
#resource_changes ⇒ Array<Google::Apis::ConfigV1::ResourceChange>
List of ResourceChanges.
Corresponds to the JSON property resourceChanges
1290 1291 1292 |
# File 'lib/google/apis/config_v1/classes.rb', line 1290 def resource_changes @resource_changes end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1295 1296 1297 |
# File 'lib/google/apis/config_v1/classes.rb', line 1295 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1302 1303 1304 1305 1306 |
# File 'lib/google/apis/config_v1/classes.rb', line 1302 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resource_changes = args[:resource_changes] if args.key?(:resource_changes) @unreachable = args[:unreachable] if args.key?(:unreachable) end |