Class: Google::Apis::ConfigV1::ListResourceDriftsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

A response to a 'ListResourceDrifts' call. Contains a list of ResourceDrifts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListResourceDriftsResponse

Returns a new instance of ListResourceDriftsResponse.



1330
1331
1332
# File 'lib/google/apis/config_v1/classes.rb', line 1330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the 'ListResourceDrifts' method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1318
1319
1320
# File 'lib/google/apis/config_v1/classes.rb', line 1318

def next_page_token
  @next_page_token
end

#resource_driftsArray<Google::Apis::ConfigV1::ResourceDrift>

List of ResourceDrifts. Corresponds to the JSON property resourceDrifts



1323
1324
1325
# File 'lib/google/apis/config_v1/classes.rb', line 1323

def resource_drifts
  @resource_drifts
end

#unreachableArray<String>

Unreachable resources, if any. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1328
1329
1330
# File 'lib/google/apis/config_v1/classes.rb', line 1328

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1335
1336
1337
1338
1339
# File 'lib/google/apis/config_v1/classes.rb', line 1335

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resource_drifts = args[:resource_drifts] if args.key?(:resource_drifts)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end