Class: Google::Apis::ConfigV1::ListResourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::ListResourcesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
A response to a 'ListResources' call. Contains a list of Resources.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the 'ListResources' method.
-
#resources ⇒ Array<Google::Apis::ConfigV1::Resource>
List of Resources.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListResourcesResponse
constructor
A new instance of ListResourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListResourcesResponse
Returns a new instance of ListResourcesResponse.
1362 1363 1364 |
# File 'lib/google/apis/config_v1/classes.rb', line 1362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the 'ListResources' method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
1350 1351 1352 |
# File 'lib/google/apis/config_v1/classes.rb', line 1350 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::ConfigV1::Resource>
List of Resources.
Corresponds to the JSON property resources
1355 1356 1357 |
# File 'lib/google/apis/config_v1/classes.rb', line 1355 def resources @resources end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1360 1361 1362 |
# File 'lib/google/apis/config_v1/classes.rb', line 1360 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1367 1368 1369 1370 1371 |
# File 'lib/google/apis/config_v1/classes.rb', line 1367 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |