Class: Google::Apis::ConfigV1::ListRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::ListRevisionsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
A response to a 'ListRevisions' call. Contains a list of Revisions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the 'ListRevisions' method.
-
#revisions ⇒ Array<Google::Apis::ConfigV1::Revision>
List of Revisions.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRevisionsResponse
constructor
A new instance of ListRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRevisionsResponse
Returns a new instance of ListRevisionsResponse.
1401 1402 1403 |
# File 'lib/google/apis/config_v1/classes.rb', line 1401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the 'ListRevisions' method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
1389 1390 1391 |
# File 'lib/google/apis/config_v1/classes.rb', line 1389 def next_page_token @next_page_token end |
#revisions ⇒ Array<Google::Apis::ConfigV1::Revision>
List of Revisions.
Corresponds to the JSON property revisions
1394 1395 1396 |
# File 'lib/google/apis/config_v1/classes.rb', line 1394 def revisions @revisions end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1399 1400 1401 |
# File 'lib/google/apis/config_v1/classes.rb', line 1399 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1406 1407 1408 1409 1410 |
# File 'lib/google/apis/config_v1/classes.rb', line 1406 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @revisions = args[:revisions] if args.key?(:revisions) @unreachable = args[:unreachable] if args.key?(:unreachable) end |