Class: Google::Apis::ConfigV1::LockInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

Details about the lock which locked the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LockInfo

Returns a new instance of LockInfo.



1532
1533
1534
# File 'lib/google/apis/config_v1/classes.rb', line 1532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Time that the lock was taken. Corresponds to the JSON property createTime

Returns:

  • (String)


1505
1506
1507
# File 'lib/google/apis/config_v1/classes.rb', line 1505

def create_time
  @create_time
end

#infoString

Extra information to store with the lock, provided by the caller. Corresponds to the JSON property info

Returns:

  • (String)


1510
1511
1512
# File 'lib/google/apis/config_v1/classes.rb', line 1510

def info
  @info
end

#lock_idFixnum

Unique ID for the lock to be overridden with generation ID in the backend. Corresponds to the JSON property lockId

Returns:

  • (Fixnum)


1515
1516
1517
# File 'lib/google/apis/config_v1/classes.rb', line 1515

def lock_id
  @lock_id
end

#operationString

Terraform operation, provided by the caller. Corresponds to the JSON property operation

Returns:

  • (String)


1520
1521
1522
# File 'lib/google/apis/config_v1/classes.rb', line 1520

def operation
  @operation
end

#versionString

Terraform version Corresponds to the JSON property version

Returns:

  • (String)


1525
1526
1527
# File 'lib/google/apis/config_v1/classes.rb', line 1525

def version
  @version
end

#whoString

user@hostname when available Corresponds to the JSON property who

Returns:

  • (String)


1530
1531
1532
# File 'lib/google/apis/config_v1/classes.rb', line 1530

def who
  @who
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/google/apis/config_v1/classes.rb', line 1537

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @info = args[:info] if args.key?(:info)
  @lock_id = args[:lock_id] if args.key?(:lock_id)
  @operation = args[:operation] if args.key?(:operation)
  @version = args[:version] if args.key?(:version)
  @who = args[:who] if args.key?(:who)
end