Class: Google::Apis::ConfigV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::OperationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#deployment_metadata ⇒ Google::Apis::ConfigV1::DeploymentOperationMetadata
Ephemeral metadata content describing the state of a deployment operation.
-
#end_time ⇒ String
Output only.
-
#preview_metadata ⇒ Google::Apis::ConfigV1::PreviewOperationMetadata
Ephemeral metadata content describing the state of a preview operation.
-
#provision_deployment_group_metadata ⇒ Google::Apis::ConfigV1::ProvisionDeploymentGroupOperationMetadata
Operation metadata for
ProvisionDeploymentGroupandDeprovisionDeploymentGrouplong-running operations. -
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
1668 1669 1670 |
# File 'lib/google/apis/config_v1/classes.rb', line 1668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
1616 1617 1618 |
# File 'lib/google/apis/config_v1/classes.rb', line 1616 def api_version @api_version end |
#create_time ⇒ String
Output only. Time when the operation was created.
Corresponds to the JSON property createTime
1621 1622 1623 |
# File 'lib/google/apis/config_v1/classes.rb', line 1621 def create_time @create_time end |
#deployment_metadata ⇒ Google::Apis::ConfigV1::DeploymentOperationMetadata
Ephemeral metadata content describing the state of a deployment operation.
Corresponds to the JSON property deploymentMetadata
1626 1627 1628 |
# File 'lib/google/apis/config_v1/classes.rb', line 1626 def @deployment_metadata end |
#end_time ⇒ String
Output only. Time when the operation finished running.
Corresponds to the JSON property endTime
1631 1632 1633 |
# File 'lib/google/apis/config_v1/classes.rb', line 1631 def end_time @end_time end |
#preview_metadata ⇒ Google::Apis::ConfigV1::PreviewOperationMetadata
Ephemeral metadata content describing the state of a preview operation.
Corresponds to the JSON property previewMetadata
1636 1637 1638 |
# File 'lib/google/apis/config_v1/classes.rb', line 1636 def @preview_metadata end |
#provision_deployment_group_metadata ⇒ Google::Apis::ConfigV1::ProvisionDeploymentGroupOperationMetadata
Operation metadata for ProvisionDeploymentGroup and
DeprovisionDeploymentGroup long-running operations.
Corresponds to the JSON property provisionDeploymentGroupMetadata
1642 1643 1644 |
# File 'lib/google/apis/config_v1/classes.rb', line 1642 def @provision_deployment_group_metadata end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property requestedCancellation
1650 1651 1652 |
# File 'lib/google/apis/config_v1/classes.rb', line 1650 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
1656 1657 1658 |
# File 'lib/google/apis/config_v1/classes.rb', line 1656 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
1661 1662 1663 |
# File 'lib/google/apis/config_v1/classes.rb', line 1661 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
1666 1667 1668 |
# File 'lib/google/apis/config_v1/classes.rb', line 1666 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 |
# File 'lib/google/apis/config_v1/classes.rb', line 1673 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @deployment_metadata = args[:deployment_metadata] if args.key?(:deployment_metadata) @end_time = args[:end_time] if args.key?(:end_time) @preview_metadata = args[:preview_metadata] if args.key?(:preview_metadata) @provision_deployment_group_metadata = args[:provision_deployment_group_metadata] if args.key?(:provision_deployment_group_metadata) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |