Class: Google::Apis::ConfigV1::ProvisionDeploymentGroupRequest
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::ProvisionDeploymentGroupRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
The request message for the ProvisionDeploymentGroup method.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProvisionDeploymentGroupRequest
constructor
A new instance of ProvisionDeploymentGroupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProvisionDeploymentGroupRequest
Returns a new instance of ProvisionDeploymentGroupRequest.
2191 2192 2193 |
# File 'lib/google/apis/config_v1/classes.rb', line 2191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_specs ⇒ Hash<String,Google::Apis::ConfigV1::DeploymentSpec>
Optional. The deployment specs of the deployment units to be created within
the same project and location of the deployment group. The key is the unit ID,
and the value is the DeploymentSpec. Provisioning will fail if a
deployment_spec has a deployment_id that matches an existing deployment in
the same project and location. If an existing deployment was part of the last
successful revision but is no longer in the current DeploymentGroup's
deployment_units, it will be recreated if included in deployment_specs.
Corresponds to the JSON property deploymentSpecs
2189 2190 2191 |
# File 'lib/google/apis/config_v1/classes.rb', line 2189 def deployment_specs @deployment_specs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2196 2197 2198 |
# File 'lib/google/apis/config_v1/classes.rb', line 2196 def update!(**args) @deployment_specs = args[:deployment_specs] if args.key?(:deployment_specs) end |