Class: Google::Apis::ConfigV1::Revision

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

A child resource of a Deployment generated by a 'CreateDeployment' or ' UpdateDeployment' call. Each Revision contains metadata pertaining to a snapshot of a particular Deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Revision

Returns a new instance of Revision.



2590
2591
2592
# File 'lib/google/apis/config_v1/classes.rb', line 2590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. The action which created this revision Corresponds to the JSON property action

Returns:

  • (String)


2466
2467
2468
# File 'lib/google/apis/config_v1/classes.rb', line 2466

def action
  @action
end

#apply_resultsGoogle::Apis::ConfigV1::ApplyResults

Outputs and artifacts from applying a deployment. Corresponds to the JSON property applyResults



2471
2472
2473
# File 'lib/google/apis/config_v1/classes.rb', line 2471

def apply_results
  @apply_results
end

#buildString

Output only. Cloud Build instance UUID associated with this revision. Corresponds to the JSON property build

Returns:

  • (String)


2476
2477
2478
# File 'lib/google/apis/config_v1/classes.rb', line 2476

def build
  @build
end

#create_timeString

Output only. Time when the revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2481
2482
2483
# File 'lib/google/apis/config_v1/classes.rb', line 2481

def create_time
  @create_time
end

#error_codeString

Output only. Code describing any errors that may have occurred. Corresponds to the JSON property errorCode

Returns:

  • (String)


2486
2487
2488
# File 'lib/google/apis/config_v1/classes.rb', line 2486

def error_code
  @error_code
end

#error_logsString

Output only. Location of Terraform error logs in Google Cloud Storage. Format: gs://bucket/object`. Corresponds to the JSON propertyerrorLogs`

Returns:

  • (String)


2492
2493
2494
# File 'lib/google/apis/config_v1/classes.rb', line 2492

def error_logs
  @error_logs
end

#import_existing_resourcesBoolean Also known as: import_existing_resources?

Output only. By default, Infra Manager will return a failure when Terraform encounters a 409 code (resource conflict error) during actuation. If this flag is set to true, Infra Manager will instead attempt to automatically import the resource into the Terraform state (for supported resource types) and continue actuation. Not all resource types are supported, refer to documentation. Corresponds to the JSON property importExistingResources

Returns:

  • (Boolean)


2501
2502
2503
# File 'lib/google/apis/config_v1/classes.rb', line 2501

def import_existing_resources
  @import_existing_resources
end

#logsString

Output only. Location of Revision operation logs in gs://bucket/object` format. Corresponds to the JSON propertylogs`

Returns:

  • (String)


2508
2509
2510
# File 'lib/google/apis/config_v1/classes.rb', line 2508

def logs
  @logs
end

#nameString

Revision name. Format: projects/project/locations/location/deployments/ deployment/ revisions/revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


2514
2515
2516
# File 'lib/google/apis/config_v1/classes.rb', line 2514

def name
  @name
end

#provider_configGoogle::Apis::ConfigV1::ProviderConfig

ProviderConfig contains the provider configurations. Corresponds to the JSON property providerConfig



2519
2520
2521
# File 'lib/google/apis/config_v1/classes.rb', line 2519

def provider_config
  @provider_config
end

#quota_validationString

Optional. Input to control quota checks for resources in terraform configuration files. There are limited resources on which quota validation applies. Corresponds to the JSON property quotaValidation

Returns:

  • (String)


2526
2527
2528
# File 'lib/google/apis/config_v1/classes.rb', line 2526

def quota_validation
  @quota_validation
end

#quota_validation_resultsString

Output only. Cloud Storage path containing quota validation results. This field is set when a user sets Deployment.quota_validation field to ENABLED or ENFORCED. Format: gs://bucket/object`. Corresponds to the JSON propertyquotaValidationResults`

Returns:

  • (String)


2533
2534
2535
# File 'lib/google/apis/config_v1/classes.rb', line 2533

def quota_validation_results
  @quota_validation_results
end

#service_accountString

Output only. User-specified Service Account (SA) to be used as credential to manage resources. Format: projects/projectID/serviceAccounts/ serviceAccount` Corresponds to the JSON propertyserviceAccount`

Returns:

  • (String)


2540
2541
2542
# File 'lib/google/apis/config_v1/classes.rb', line 2540

def 
  @service_account
end

#stateString

Output only. Current state of the revision. Corresponds to the JSON property state

Returns:

  • (String)


2545
2546
2547
# File 'lib/google/apis/config_v1/classes.rb', line 2545

def state
  @state
end

#state_detailString

Output only. Additional info regarding the current state. Corresponds to the JSON property stateDetail

Returns:

  • (String)


2550
2551
2552
# File 'lib/google/apis/config_v1/classes.rb', line 2550

def state_detail
  @state_detail
end

#terraform_blueprintGoogle::Apis::ConfigV1::TerraformBlueprint

TerraformBlueprint describes the source of a Terraform root module which describes the resources and configs to be deployed. Corresponds to the JSON property terraformBlueprint



2556
2557
2558
# File 'lib/google/apis/config_v1/classes.rb', line 2556

def terraform_blueprint
  @terraform_blueprint
end

#tf_errorsArray<Google::Apis::ConfigV1::TerraformError>

Output only. Errors encountered when creating or updating this deployment. Errors are truncated to 10 entries, see delete_results and error_logs for full details. Corresponds to the JSON property tfErrors



2563
2564
2565
# File 'lib/google/apis/config_v1/classes.rb', line 2563

def tf_errors
  @tf_errors
end

#tf_versionString

Output only. The version of Terraform used to create the Revision. It is in the format of "Major.Minor.Patch", for example, "1.3.10". Corresponds to the JSON property tfVersion

Returns:

  • (String)


2569
2570
2571
# File 'lib/google/apis/config_v1/classes.rb', line 2569

def tf_version
  @tf_version
end

#tf_version_constraintString

Output only. The user-specified Terraform version constraint. Example: "=1.3. 10". Corresponds to the JSON property tfVersionConstraint

Returns:

  • (String)


2575
2576
2577
# File 'lib/google/apis/config_v1/classes.rb', line 2575

def tf_version_constraint
  @tf_version_constraint
end

#update_timeString

Output only. Time when the revision was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


2580
2581
2582
# File 'lib/google/apis/config_v1/classes.rb', line 2580

def update_time
  @update_time
end

#worker_poolString

Output only. The user-specified Cloud Build worker pool resource in which the Cloud Build job will execute. Format: projects/project/locations/location/ workerPools/workerPoolId`. If this field is unspecified, the default Cloud Build worker pool will be used. Corresponds to the JSON propertyworkerPool`

Returns:

  • (String)


2588
2589
2590
# File 'lib/google/apis/config_v1/classes.rb', line 2588

def worker_pool
  @worker_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
# File 'lib/google/apis/config_v1/classes.rb', line 2595

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @apply_results = args[:apply_results] if args.key?(:apply_results)
  @build = args[:build] if args.key?(:build)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_logs = args[:error_logs] if args.key?(:error_logs)
  @import_existing_resources = args[:import_existing_resources] if args.key?(:import_existing_resources)
  @logs = args[:logs] if args.key?(:logs)
  @name = args[:name] if args.key?(:name)
  @provider_config = args[:provider_config] if args.key?(:provider_config)
  @quota_validation = args[:quota_validation] if args.key?(:quota_validation)
  @quota_validation_results = args[:quota_validation_results] if args.key?(:quota_validation_results)
  @service_account = args[:service_account] if args.key?(:service_account)
  @state = args[:state] if args.key?(:state)
  @state_detail = args[:state_detail] if args.key?(:state_detail)
  @terraform_blueprint = args[:terraform_blueprint] if args.key?(:terraform_blueprint)
  @tf_errors = args[:tf_errors] if args.key?(:tf_errors)
  @tf_version = args[:tf_version] if args.key?(:tf_version)
  @tf_version_constraint = args[:tf_version_constraint] if args.key?(:tf_version_constraint)
  @update_time = args[:update_time] if args.key?(:update_time)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
end