Class: Google::Apis::ConfigV1::Revision
- Inherits:
-
Object
- Object
- Google::Apis::ConfigV1::Revision
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb
Overview
A child resource of a Deployment generated by a 'CreateDeployment' or ' UpdateDeployment' call. Each Revision contains metadata pertaining to a snapshot of a particular Deployment.
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#apply_results ⇒ Google::Apis::ConfigV1::ApplyResults
Outputs and artifacts from applying a deployment.
-
#build ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#error_code ⇒ String
Output only.
-
#error_logs ⇒ String
Output only.
-
#import_existing_resources ⇒ Boolean
(also: #import_existing_resources?)
Output only.
-
#logs ⇒ String
Output only.
-
#name ⇒ String
Revision name.
-
#provider_config ⇒ Google::Apis::ConfigV1::ProviderConfig
ProviderConfig contains the provider configurations.
-
#quota_validation ⇒ String
Optional.
-
#quota_validation_results ⇒ String
Output only.
-
#service_account ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_detail ⇒ String
Output only.
-
#terraform_blueprint ⇒ Google::Apis::ConfigV1::TerraformBlueprint
TerraformBlueprint describes the source of a Terraform root module which describes the resources and configs to be deployed.
-
#tf_errors ⇒ Array<Google::Apis::ConfigV1::TerraformError>
Output only.
-
#tf_version ⇒ String
Output only.
-
#tf_version_constraint ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#worker_pool ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Revision
constructor
A new instance of Revision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Revision
Returns a new instance of Revision.
2583 2584 2585 |
# File 'lib/google/apis/config_v1/classes.rb', line 2583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. The action which created this revision
Corresponds to the JSON property action
2459 2460 2461 |
# File 'lib/google/apis/config_v1/classes.rb', line 2459 def action @action end |
#apply_results ⇒ Google::Apis::ConfigV1::ApplyResults
Outputs and artifacts from applying a deployment.
Corresponds to the JSON property applyResults
2464 2465 2466 |
# File 'lib/google/apis/config_v1/classes.rb', line 2464 def apply_results @apply_results end |
#build ⇒ String
Output only. Cloud Build instance UUID associated with this revision.
Corresponds to the JSON property build
2469 2470 2471 |
# File 'lib/google/apis/config_v1/classes.rb', line 2469 def build @build end |
#create_time ⇒ String
Output only. Time when the revision was created.
Corresponds to the JSON property createTime
2474 2475 2476 |
# File 'lib/google/apis/config_v1/classes.rb', line 2474 def create_time @create_time end |
#error_code ⇒ String
Output only. Code describing any errors that may have occurred.
Corresponds to the JSON property errorCode
2479 2480 2481 |
# File 'lib/google/apis/config_v1/classes.rb', line 2479 def error_code @error_code end |
#error_logs ⇒ String
Output only. Location of Terraform error logs in Google Cloud Storage. Format:
gs://bucket/object`.
Corresponds to the JSON propertyerrorLogs`
2485 2486 2487 |
# File 'lib/google/apis/config_v1/classes.rb', line 2485 def error_logs @error_logs end |
#import_existing_resources ⇒ Boolean Also known as: import_existing_resources?
Output only. By default, Infra Manager will return a failure when Terraform
encounters a 409 code (resource conflict error) during actuation. If this flag
is set to true, Infra Manager will instead attempt to automatically import the
resource into the Terraform state (for supported resource types) and continue
actuation. Not all resource types are supported, refer to documentation.
Corresponds to the JSON property importExistingResources
2494 2495 2496 |
# File 'lib/google/apis/config_v1/classes.rb', line 2494 def import_existing_resources @import_existing_resources end |
#logs ⇒ String
Output only. Location of Revision operation logs in gs://bucket/object`
format.
Corresponds to the JSON propertylogs`
2501 2502 2503 |
# File 'lib/google/apis/config_v1/classes.rb', line 2501 def logs @logs end |
#name ⇒ String
Revision name. Format: projects/project/locations/location/deployments/
deployment/ revisions/revision`
Corresponds to the JSON propertyname`
2507 2508 2509 |
# File 'lib/google/apis/config_v1/classes.rb', line 2507 def name @name end |
#provider_config ⇒ Google::Apis::ConfigV1::ProviderConfig
ProviderConfig contains the provider configurations.
Corresponds to the JSON property providerConfig
2512 2513 2514 |
# File 'lib/google/apis/config_v1/classes.rb', line 2512 def provider_config @provider_config end |
#quota_validation ⇒ String
Optional. Input to control quota checks for resources in terraform
configuration files. There are limited resources on which quota validation
applies.
Corresponds to the JSON property quotaValidation
2519 2520 2521 |
# File 'lib/google/apis/config_v1/classes.rb', line 2519 def quota_validation @quota_validation end |
#quota_validation_results ⇒ String
Output only. Cloud Storage path containing quota validation results. This
field is set when a user sets Deployment.quota_validation field to ENABLED or
ENFORCED. Format: gs://bucket/object`.
Corresponds to the JSON propertyquotaValidationResults`
2526 2527 2528 |
# File 'lib/google/apis/config_v1/classes.rb', line 2526 def quota_validation_results @quota_validation_results end |
#service_account ⇒ String
Output only. User-specified Service Account (SA) to be used as credential to
manage resources. Format: projects/projectID/serviceAccounts/
serviceAccount`
Corresponds to the JSON propertyserviceAccount`
2533 2534 2535 |
# File 'lib/google/apis/config_v1/classes.rb', line 2533 def service_account @service_account end |
#state ⇒ String
Output only. Current state of the revision.
Corresponds to the JSON property state
2538 2539 2540 |
# File 'lib/google/apis/config_v1/classes.rb', line 2538 def state @state end |
#state_detail ⇒ String
Output only. Additional info regarding the current state.
Corresponds to the JSON property stateDetail
2543 2544 2545 |
# File 'lib/google/apis/config_v1/classes.rb', line 2543 def state_detail @state_detail end |
#terraform_blueprint ⇒ Google::Apis::ConfigV1::TerraformBlueprint
TerraformBlueprint describes the source of a Terraform root module which
describes the resources and configs to be deployed.
Corresponds to the JSON property terraformBlueprint
2549 2550 2551 |
# File 'lib/google/apis/config_v1/classes.rb', line 2549 def terraform_blueprint @terraform_blueprint end |
#tf_errors ⇒ Array<Google::Apis::ConfigV1::TerraformError>
Output only. Errors encountered when creating or updating this deployment.
Errors are truncated to 10 entries, see delete_results and error_logs for
full details.
Corresponds to the JSON property tfErrors
2556 2557 2558 |
# File 'lib/google/apis/config_v1/classes.rb', line 2556 def tf_errors @tf_errors end |
#tf_version ⇒ String
Output only. The version of Terraform used to create the Revision. It is in
the format of "Major.Minor.Patch", for example, "1.3.10".
Corresponds to the JSON property tfVersion
2562 2563 2564 |
# File 'lib/google/apis/config_v1/classes.rb', line 2562 def tf_version @tf_version end |
#tf_version_constraint ⇒ String
Output only. The user-specified Terraform version constraint. Example: "=1.3.
10".
Corresponds to the JSON property tfVersionConstraint
2568 2569 2570 |
# File 'lib/google/apis/config_v1/classes.rb', line 2568 def tf_version_constraint @tf_version_constraint end |
#update_time ⇒ String
Output only. Time when the revision was last modified.
Corresponds to the JSON property updateTime
2573 2574 2575 |
# File 'lib/google/apis/config_v1/classes.rb', line 2573 def update_time @update_time end |
#worker_pool ⇒ String
Output only. The user-specified Cloud Build worker pool resource in which the
Cloud Build job will execute. Format: projects/project/locations/location/
workerPools/workerPoolId`. If this field is unspecified, the default Cloud
Build worker pool will be used.
Corresponds to the JSON propertyworkerPool`
2581 2582 2583 |
# File 'lib/google/apis/config_v1/classes.rb', line 2581 def worker_pool @worker_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 |
# File 'lib/google/apis/config_v1/classes.rb', line 2588 def update!(**args) @action = args[:action] if args.key?(:action) @apply_results = args[:apply_results] if args.key?(:apply_results) @build = args[:build] if args.key?(:build) @create_time = args[:create_time] if args.key?(:create_time) @error_code = args[:error_code] if args.key?(:error_code) @error_logs = args[:error_logs] if args.key?(:error_logs) @import_existing_resources = args[:import_existing_resources] if args.key?(:import_existing_resources) @logs = args[:logs] if args.key?(:logs) @name = args[:name] if args.key?(:name) @provider_config = args[:provider_config] if args.key?(:provider_config) @quota_validation = args[:quota_validation] if args.key?(:quota_validation) @quota_validation_results = args[:quota_validation_results] if args.key?(:quota_validation_results) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) @state_detail = args[:state_detail] if args.key?(:state_detail) @terraform_blueprint = args[:terraform_blueprint] if args.key?(:terraform_blueprint) @tf_errors = args[:tf_errors] if args.key?(:tf_errors) @tf_version = args[:tf_version] if args.key?(:tf_version) @tf_version_constraint = args[:tf_version_constraint] if args.key?(:tf_version_constraint) @update_time = args[:update_time] if args.key?(:update_time) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) end |