Class: Google::Apis::ConfigV1::TerraformBlueprint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

TerraformBlueprint describes the source of a Terraform root module which describes the resources and configs to be deployed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TerraformBlueprint

Returns a new instance of TerraformBlueprint.



2753
2754
2755
# File 'lib/google/apis/config_v1/classes.rb', line 2753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_valuesHash<String,Google::Apis::ConfigV1::ExternalValueSource>

Optional. Map of input variable names in this blueprint to configurations for importing values from external sources. Corresponds to the JSON property externalValues



2734
2735
2736
# File 'lib/google/apis/config_v1/classes.rb', line 2734

def external_values
  @external_values
end

#gcs_sourceString

URI of an object in Google Cloud Storage. Format: gs://bucket/objectURI may also specify an object version for zipped objects. Format: `gs://`bucket`/` object`#`version Corresponds to the JSON property gcsSource

Returns:

  • (String)


2741
2742
2743
# File 'lib/google/apis/config_v1/classes.rb', line 2741

def gcs_source
  @gcs_source
end

#git_sourceGoogle::Apis::ConfigV1::GitSource

A set of files in a Git repository. Corresponds to the JSON property gitSource



2746
2747
2748
# File 'lib/google/apis/config_v1/classes.rb', line 2746

def git_source
  @git_source
end

#input_valuesHash<String,Google::Apis::ConfigV1::TerraformVariable>

Optional. Input variable values for the Terraform blueprint. Corresponds to the JSON property inputValues



2751
2752
2753
# File 'lib/google/apis/config_v1/classes.rb', line 2751

def input_values
  @input_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2758
2759
2760
2761
2762
2763
# File 'lib/google/apis/config_v1/classes.rb', line 2758

def update!(**args)
  @external_values = args[:external_values] if args.key?(:external_values)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @git_source = args[:git_source] if args.key?(:git_source)
  @input_values = args[:input_values] if args.key?(:input_values)
end