Class: Google::Apis::ConfigV1::TerraformError

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/config_v1/classes.rb,
lib/google/apis/config_v1/representations.rb,
lib/google/apis/config_v1/representations.rb

Overview

Errors encountered during actuation using Terraform

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TerraformError

Returns a new instance of TerraformError.



2805
2806
2807
# File 'lib/google/apis/config_v1/classes.rb', line 2805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ConfigV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2785
2786
2787
# File 'lib/google/apis/config_v1/classes.rb', line 2785

def error
  @error
end

#error_descriptionString

A human-readable error description. Corresponds to the JSON property errorDescription

Returns:

  • (String)


2790
2791
2792
# File 'lib/google/apis/config_v1/classes.rb', line 2790

def error_description
  @error_description
end

#http_response_codeFixnum

HTTP response code returned from Google Cloud Platform APIs when Terraform fails to provision the resource. If unset or 0, no HTTP response code was returned by Terraform. Corresponds to the JSON property httpResponseCode

Returns:

  • (Fixnum)


2797
2798
2799
# File 'lib/google/apis/config_v1/classes.rb', line 2797

def http_response_code
  @http_response_code
end

#resource_addressString

Address of the resource associated with the error, e.g. google_compute_network.vpc_network. Corresponds to the JSON property resourceAddress

Returns:

  • (String)


2803
2804
2805
# File 'lib/google/apis/config_v1/classes.rb', line 2803

def resource_address
  @resource_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2810
2811
2812
2813
2814
2815
# File 'lib/google/apis/config_v1/classes.rb', line 2810

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @error_description = args[:error_description] if args.key?(:error_description)
  @http_response_code = args[:http_response_code] if args.key?(:http_response_code)
  @resource_address = args[:resource_address] if args.key?(:resource_address)
end